Homogeneous Spaces Submodule
============================

.. module:: beluga.liepack.domain.hspaces

Introduction
------------

Base Class Reference
--------------------

.. autoclass:: HManifold
    :members: left, right
